#
# spec file for package dbgl
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realver 098
%define java_version 21
Name:           dbgl
Version:        0.98
Release:        1.1
Summary:        DOSBox Game Launcher
License:        GPL-2.0-only
Group:          System/Emulators/Other
URL:            https://dbgl.org
Source0:        https://dbgl.org/download/src%{realver}.zip
Source1:        %{name}-wrapper.sh
Source2:        %{name}.appdata.xml
Patch0:         fix-swt-color.patch
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-text
BuildRequires:  eclipse-swt
BuildRequires:  java-devel >= %{java_version}
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       apache-commons-io
Requires:       apache-commons-lang3
Requires:       apache-commons-text
Requires:       dosbox >= 0.70
Requires:       eclipse-swt
Requires:       java >= %{java_version}
Requires:       javapackages-tools
BuildArch:      noarch

%description
DBGL is a Java front-end for DOSBox, based largely upon the
proven interface of D-Fend.

%prep
%setup -q -c
%autopatch -p1
# unbundle libs
rm ./src/dist/shared/lib/commons-lang3-*.jar
rm ./src/dist/shared/lib/commons-io-*.jar
rm ./src/dist/shared/lib/commons-text-*.jar

%build
mkdir -p lib
build-jar-repository -s -p libtest commons-io commons-lang3 apache-commons-text swt
ant distlinux

%install
install -D -m0755 %{SOURCE1} %{buildroot}/%{_bindir}/%{name}
install -d %{buildroot}%{_javadir}/dbgl
tar xvf dist/dbgl%{realver}.tar.gz -C %{buildroot}%{_javadir}/dbgl/
# Use symbol links to system libraries
build-jar-repository -s -p %{buildroot}/%{_javadir}/%{name}/lib commons-io commons-lang3 apache-commons-text swt
#
install -d %{buildroot}%{_datadir}/pixmaps
mv %{buildroot}%{_javadir}/%{name}/dbgl.png %{buildroot}%{_datadir}/pixmaps/
install -D -pm0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/dbgl.appdata.xml
%suse_update_desktop_file -c %{name} %{name} "DOSBox Game Launcher" %{name} %{name} Game Emulator
# Remove not needed files
rm %{buildroot}%{_javadir}/dbgl/lib/swtlin64.jar
rm %{buildroot}%{_javadir}/dbgl/dbgl

%files
%license src/dist/shared/COPYING
%{_bindir}/dbgl
%{_javadir}/dbgl
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Thu Oct 31 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.98:
  * Added support for eXoDOS V6 and V6r2. While both the convertor
    and importer have been improved, using the importer has
    advantages; it has the ability to import the custom DOSBox
    versions that come with eXoDOS, creates filter tabs for
    Playlists and can import the Media Pack Add-On and soundfonts.
    More details can be found in section Game collection management
  * Added support for the IBM Music Feature Card, in the profile
    editor.
  * Slovakian translation update.
  * Implemented a workaround for strange zipfile check which
    prevented certain GamePackArchives from being imported on
    modern Java versions.
  * Implemented another workaround for SWT bug resulting in broken
    artwork on Linux.
  * Allow parent directories to be considered relative, if
    configured as such.
  * Display image dimensions in thumb dialog title.
  * Fixed a few crash bugs: when DOSBox dynamic options are somehow
    invalid (red_avatar), when editing an imgmount with fstype=none
    or when creating a filter with a very lengthy condition.
  * Updated multiple Java libraries, most importantly SWT which now
    requires Java 17.
* Mon Nov  6 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.97:
  * Too many changes to be listed here, please read the changes at
    https://dbgl.org/#changelog
- Update the source url and the package main url
- Add patch:
  * fix-swt-color.patch
* Wed Jul 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.92
  * Added a first implementation of 'directory scanning for known
    games'. Currently, all files/games from the D-Fend Reloaded
    'Auto setup templates' are recognized.
  * DBGL can now query MobyGames meta-data using a local database
    from 'Metropolis Launcher', very quickly. Note that cover-art
    and screenshots are still being fetched from www.mobygames.com,
    though.
  * Added support for the DOSBox SVN OpenGL shader patch from
    ny00123 & jmarsh.
  * You may now browse through the various captured images using
    the left and right arrow keys, or the buttons below the image.
  * Various fixes related to MobyGames querying, especially in
    relation to (.gif) image data.
  * Fixed "Start profile manually with a specific DOSBox version"
    creating an incomplete .conf file.
  * Fixed possible issues when using symbolic links on Linux.
  * Also fixed a rare file path mangling issue.
  * A few usability improvements, refactored more parts of the
    GUI code, updated translations.
  * Updated all libraries, most importantly HSQLDB (from 1.8.1 to
    2.5.0).
* Sun Jun 28 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.91
